@@ -115,7 +115,7 @@ ephy_permissions_manager_get_settings_for_origin (EphyPermissionsManager *manage
   if (settings)
     return settings;
 
-  filename = g_build_filename (ephy_dot_dir (), PERMISSIONS_FILENAME, NULL);
+  filename = g_build_filename (ephy_profile_dir (), PERMISSIONS_FILENAME, NULL);
   backend = g_keyfile_settings_backend_new (filename, "/", NULL);
   g_free (filename);
 
@@ -164,6 +164,8 @@ permission_type_to_string (EphyPermissionType type)
     return "audio-device-permission";
   case EPHY_PERMISSION_TYPE_ACCESS_WEBCAM:
     return "video-device-permission";
+  case EPHY_PERMISSION_TYPE_SHOW_ADS:
+    return "advertisement-permission";
   default:
     g_assert_not_reached ();
   }
@@ -354,7 +356,7 @@ ephy_permissions_manager_get_matching_origins (EphyPermissionsManager *manager,
 {
   GKeyFile *file;
   char *filename;
-  char **groups;
+  char **groups = NULL;
   gsize groups_length;
   GList *origins = NULL;
   GError *error = NULL;
@@ -373,14 +375,14 @@ ephy_permissions_manager_get_matching_origins (EphyPermissionsManager *manager,
   /* Not cached. Load results from GSettings keyfile. Do it manually because the
    * GSettings API is not designed to be used for enumerating settings. */
   file = g_key_file_new ();
-  filename = g_build_filename (ephy_dot_dir (), PERMISSIONS_FILENAME, NULL);
+  filename = g_build_filename (ephy_profile_dir (), PERMISSIONS_FILENAME, NULL);
 
   g_key_file_load_from_file (file, filename, G_KEY_FILE_NONE, &error);
   if (error != NULL) {
     if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT))
       g_warning ("Error processing %s: %s", filename, error->message);
     g_error_free (error);
-    return NULL;
+    goto out;
   }
 
   groups = g_key_file_get_groups (file, &groups_length);
@@ -388,10 +390,6 @@ ephy_permissions_manager_get_matching_origins (EphyPermissionsManager *manager,
     origins = g_list_concat (origins,
                              origins_for_keyfile_group (file, filename, groups[i], type, permit));
 
-  g_key_file_unref (file);
-  g_strfreev (groups);
-  g_free (filename);
-
   /* Cache the results. */
   if (origins != NULL) {
     g_hash_table_insert (permit ? manager->permission_type_permitted_origins
@@ -400,6 +398,11 @@ ephy_permissions_manager_get_matching_origins (EphyPermissionsManager *manager,
                          origins);
   }
 
+out:
+  g_key_file_unref (file);
+  g_strfreev (groups);
+  g_free (filename);
+
   return origins;
 }
 
@@ -416,3 +419,67 @@ ephy_permissions_manager_get_denied_origins (EphyPermissionsManager *manager,
 {
   return ephy_permissions_manager_get_matching_origins (manager, type, FALSE);
 }
+
+static EphyPermission
+js_permissions_manager_get_permission (EphyPermissionsManager *manager,
+                                       EphyPermissionType      type,
+                                       const char             *origin)
+{
+  return ephy_permissions_manager_get_permission (manager, type, origin);
+}
+
+void
+ephy_permissions_manager_export_to_js_context (EphyPermissionsManager *manager,
+                                               JSCContext             *js_context,
+                                               JSCValue               *js_namespace)
+{
+  JSCClass *js_class;
+  JSCValue *js_enum, *js_enum_value;
+  JSCValue *js_permissions_manager;
+
+  js_class = jsc_context_register_class (js_context, "PermissionsManager", NULL, NULL, NULL);
+  jsc_class_add_method (js_class,
+                        "permission",
+                        G_CALLBACK (js_permissions_manager_get_permission), NULL, NULL,
+                        G_TYPE_INT, 2,
+                        G_TYPE_INT, G_TYPE_STRING);
+
+  js_permissions_manager = jsc_value_new_object (js_context, manager, js_class);
+  jsc_value_object_set_property (js_namespace, "permissionsManager", js_permissions_manager);
+  g_object_unref (js_permissions_manager);
+
+  js_enum = jsc_value_new_object (js_context, NULL, NULL);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_UNDECIDED);
+  jsc_value_object_set_property (js_enum, "UNDECIDED", js_enum_value);
+  g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_DENY);
+  jsc_value_object_set_property (js_enum, "DENY", js_enum_value);
+  g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_PERMIT);
+  jsc_value_object_set_property (js_enum, "PERMIT", js_enum_value);
+  g_object_unref (js_enum_value);
+  jsc_value_object_set_property (js_namespace, "Permission", js_enum);
+  g_object_unref (js_enum);
+
+  js_enum = jsc_value_new_object (js_context, NULL, NULL);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_SHOW_NOTIFICATIONS);
+  jsc_value_object_set_property (js_enum, "SHOW_NOTIFICATIONS", js_enum_value);
+  g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_SAVE_PASSWORD);
+  jsc_value_object_set_property (js_enum, "SAVE_PASSWORD", js_enum_value);
+  g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_ACCESS_LOCATION);
+  jsc_value_object_set_property (js_enum, "ACCESS_LOCATION", js_enum_value);
+  g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_ACCESS_MICROPHONE);
+  jsc_value_object_set_property (js_enum, "ACCESS_MICROPHONE", js_enum_value);
+  g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_ACCESS_WEBCAM);
+  jsc_value_object_set_property (js_enum, "ACCESS_WEBCAM", js_enum_value);
+  g_object_unref (js_enum_value);
+  js_enum_value = jsc_value_new_number (js_context, EPHY_PERMISSION_TYPE_SHOW_ADS);
+  jsc_value_object_set_property (js_enum, "SHOW_ADS", js_enum_value);
+  g_object_unref (js_enum_value);
+  jsc_value_object_set_property (js_namespace, "PermissionType", js_enum);
+  g_object_unref (js_enum);
+}
