@@ -31,7 +31,8 @@
 int
 ephy_profile_utils_get_migration_version_for_profile_dir (const char *profile_directory)
 {
-  char *migrated_file, *contents = NULL;
+  g_autofree char *migrated_file = NULL;
+  g_autofree char *contents = NULL;
   gsize size;
   int result = 0;
   int latest = 0;
@@ -46,39 +47,28 @@ ephy_profile_utils_get_migration_version_for_profile_dir (const char *profile_di
     if (contents != NULL)
       result = sscanf (contents, "%d", &latest);
 
-    g_free (contents);
-
     if (result != 1)
       latest = 0;
-  } else if (strcmp (ephy_dot_dir (), profile_directory) == 0 &&
-             ephy_dot_dir_is_default () == FALSE) {
-    /* Since version 8, we need to migrate also profile directories
-       other than the default one. Profiles in such directories work
-       perfectly fine without going through the first 7 migration
-       steps, so it is safe to assume that any non-default profile
-       directory without a migration file can be migrated starting
-       from the step 8. */
-    latest = 7;
   }
 
-  g_free (migrated_file);
-
   return latest;
 }
 
 int
 ephy_profile_utils_get_migration_version (void)
 {
-  return ephy_profile_utils_get_migration_version_for_profile_dir (ephy_dot_dir ());
+  return ephy_profile_utils_get_migration_version_for_profile_dir (ephy_profile_dir ());
 }
 
 gboolean
-ephy_profile_utils_set_migration_version (int version)
+ephy_profile_utils_set_migration_version_for_profile_dir (int         version,
+                                                          const char *profile_directory)
 {
-  char *migrated_file, *contents;
+  g_autofree char *migrated_file;
+  g_autofree char *contents;
   gboolean result = FALSE;
 
-  migrated_file = g_build_filename (ephy_dot_dir (),
+  migrated_file = g_build_filename (profile_directory,
                                     PROFILE_MIGRATION_FILE,
                                     NULL);
   contents = g_strdup_printf ("%d", version);
@@ -86,26 +76,29 @@ ephy_profile_utils_set_migration_version (int version)
 
   if (result == FALSE)
     LOG ("Couldn't store migration version %d in %s (%s, %s)",
-         version, migrated_file, ephy_dot_dir (), PROFILE_MIGRATION_FILE);
-
-  g_free (contents);
-  g_free (migrated_file);
+         version, migrated_file, profile_directory, PROFILE_MIGRATION_FILE);
 
   return result;
 }
 
+gboolean
+ephy_profile_utils_set_migration_version (int version)
+{
+  return ephy_profile_utils_set_migration_version_for_profile_dir (version, ephy_profile_dir ());
+}
+
 #define EPHY_PROFILE_MIGRATOR "ephy-profile-migrator"
 
 gboolean
 ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run, gboolean debug)
 {
-  gboolean ret;
-  GError *error = NULL;
-  char *index = NULL, *version = NULL;
+  g_autoptr(GError) error = NULL;
+  g_autofree char *index = NULL;
+  g_autofree char *version = NULL;
   int status;
   const char *argv[8] = { PKGLIBEXECDIR "/" EPHY_PROFILE_MIGRATOR, "-v" };
   int i = 2; /* index for argv, start filling at 2. */
-  char **envp;
+  g_auto(GStrv) envp = NULL;
 
   envp = g_environ_setenv (g_get_environ (),
                            "EPHY_LOG_MODULES", "ephy-profile",
@@ -117,7 +110,6 @@ ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run,
      is nothing to migrate, don't spawn the migrator at all. */
   if (test_to_run == -1 &&
       EPHY_PROFILE_MIGRATION_VERSION == ephy_profile_utils_get_migration_version ()) {
-    g_strfreev (envp);
     return TRUE;
   }
 
@@ -142,20 +134,13 @@ ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run,
     argv[0] = BUILD_ROOT "/src/" EPHY_PROFILE_MIGRATOR;
 #endif
 
-  ret = g_spawn_sync (NULL, (char **)argv, envp, G_SPAWN_SEARCH_PATH,
-                      NULL, NULL, NULL, NULL,
-                      &status, &error);
-  g_free (index);
-  g_free (version);
-  g_strfreev (envp);
-
+  g_spawn_sync (NULL, (char **)argv, envp, G_SPAWN_SEARCH_PATH,
+                NULL, NULL, NULL, NULL,
+                &status, &error);
   if (error) {
     g_warning ("Failed to run migrator: %s", error->message);
-    g_error_free (error);
+    return FALSE;
   }
 
-  if (status != 0)
-    ret = FALSE;
-
-  return ret;
+  return status == 0;
 }
