@@ -22,8 +22,6 @@
 
 #include "ephy-history-service.h"
 #include "ephy-history-service-private.h"
-#include "ephy-prefs.h"
-#include "ephy-settings.h"
 #include "ephy-string.h"
 #include <glib/gi18n.h>
 
@@ -112,10 +110,6 @@ ephy_history_service_update_host_row (EphyHistoryService *self, EphyHistoryHost
 
   zoom_level = host->zoom_level;
 
-  /* Ensure that a change value which equals default zoom level is stored as 0.0 */
-  if (zoom_level == g_settings_get_double (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL))
-    zoom_level = 0.0f;
-
   if (ephy_sqlite_statement_bind_string (statement, 0, host->url, &error) == FALSE ||
       ephy_sqlite_statement_bind_string (statement, 1, host->title, &error) == FALSE ||
       ephy_sqlite_statement_bind_int (statement, 2, host->visit_count, &error) == FALSE ||
@@ -361,14 +355,14 @@ get_hostname_and_locations (const gchar *url, gchar **hostname)
     *hostname = ephy_string_get_host_name (url);
   }
   /* Build an host name */
-  if (scheme == NULL || *hostname == NULL) {
-    *hostname = g_strdup (_("Others"));
+  if (scheme != NULL && strcmp (scheme, "file") == 0) {
+    *hostname = g_strdup ("Local files");
+    host_locations = g_list_append (host_locations,
+                                    g_strdup (url));
+  } else if (scheme == NULL || *hostname == NULL) {
+    *hostname = g_strdup ("Others");
     host_locations = g_list_append (host_locations,
                                     g_strdup ("about:blank"));
-  }  else if (strcmp (scheme, "file") == 0) {
-    *hostname = g_strdup (_("Local files"));
-    host_locations = g_list_append (host_locations,
-                                    g_strdup ("file:///"));
   } else {
     char *location;
     char *tmp;
