@@ -124,7 +124,9 @@ ephy_gsb_storage_start_transaction (EphyGSBStorage *self)
   GError *error = NULL;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
+
+  if (!self->is_operable)
+    return;
 
   ephy_sqlite_connection_begin_transaction (self->db, &error);
   if (error) {
@@ -139,7 +141,9 @@ ephy_gsb_storage_end_transaction (EphyGSBStorage *self)
   GError *error = NULL;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
+
+  if (!self->is_operable)
+    return;
 
   ephy_sqlite_connection_commit_transaction (self->db, &error);
   if (error) {
@@ -378,6 +382,18 @@ ephy_gsb_storage_open_db (EphyGSBStorage *self)
   return TRUE;
 }
 
+static void
+ephy_gsb_storage_clear_db (EphyGSBStorage *self)
+{
+  g_assert (EPHY_IS_GSB_STORAGE (self));
+
+  if (self->db) {
+    ephy_sqlite_connection_close (self->db);
+    ephy_sqlite_connection_delete_database (self->db);
+    g_clear_object (&self->db);
+  }
+}
+
 static gboolean
 ephy_gsb_storage_init_db (EphyGSBStorage *self)
 {
@@ -394,15 +410,23 @@ ephy_gsb_storage_init_db (EphyGSBStorage *self)
             ephy_gsb_storage_init_hash_prefix_table (self) &&
             ephy_gsb_storage_init_hash_full_table (self);
 
-  if (!success) {
-    ephy_sqlite_connection_close (self->db);
-    ephy_sqlite_connection_delete_database (self->db);
-    g_clear_object (&self->db);
-  }
+  if (!success)
+    ephy_gsb_storage_clear_db (self);
+
+  self->is_operable = success;
 
   return success;
 }
 
+static gboolean
+ephy_gsb_storage_recreate_db (EphyGSBStorage *self)
+{
+  g_assert (EPHY_IS_GSB_STORAGE (self));
+
+  ephy_gsb_storage_clear_db (self);
+  return ephy_gsb_storage_init_db (self);
+}
+
 static inline gboolean
 ephy_gsb_storage_check_schema_version (EphyGSBStorage *self)
 {
@@ -481,14 +505,9 @@ ephy_gsb_storage_constructed (GObject *object)
     success = ephy_gsb_storage_open_db (self);
     if (success && !ephy_gsb_storage_check_schema_version (self)) {
       LOG ("GSB database schema incompatibility, recreating database...");
-      ephy_sqlite_connection_close (self->db);
-      ephy_sqlite_connection_delete_database (self->db);
-      g_clear_object (&self->db);
-      success = ephy_gsb_storage_init_db (self);
+      ephy_gsb_storage_recreate_db (self);
     }
   }
-
-  self->is_operable = success;
 }
 
 static void
@@ -585,6 +604,7 @@ ephy_gsb_storage_get_metadata (EphyGSBStorage *self,
     g_warning ("Failed to execute select metadata statement: %s", error->message);
     g_error_free (error);
     g_object_unref (statement);
+    ephy_gsb_storage_recreate_db (self);
     return default_value;
   }
 
@@ -612,9 +632,11 @@ ephy_gsb_storage_set_metadata (EphyGSBStorage *self,
   const char *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (key);
 
+  if (!self->is_operable)
+    return;
+
   sql = "UPDATE metadata SET value=? WHERE key=?";
   statement = ephy_sqlite_connection_create_statement (self->db, sql, &error);
   if (error) {
@@ -645,6 +667,7 @@ ephy_gsb_storage_set_metadata (EphyGSBStorage *self,
   if (error) {
     g_warning ("Failed to execute update metadata statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 }
 
@@ -670,7 +693,9 @@ ephy_gsb_storage_get_threat_lists (EphyGSBStorage *self)
   const char *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
+
+  if (!self->is_operable)
+    return NULL;
 
   sql = "SELECT threat_type, platform_type, threat_entry_type, client_state FROM threats";
   statement = ephy_sqlite_connection_create_statement (self->db, sql, &error);
@@ -693,6 +718,7 @@ ephy_gsb_storage_get_threat_lists (EphyGSBStorage *self)
   if (error) {
     g_warning ("Failed to execute select threat lists statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
@@ -725,9 +751,11 @@ ephy_gsb_storage_compute_checksum (EphyGSBStorage    *self,
   gsize digest_len = GSB_HASH_SIZE;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
 
+  if (!self->is_operable)
+    return NULL;
+
   sql = "SELECT value FROM hash_prefix WHERE "
         "threat_type=? AND platform_type=? AND threat_entry_type=? "
         "ORDER BY value";
@@ -753,6 +781,7 @@ ephy_gsb_storage_compute_checksum (EphyGSBStorage    *self,
   if (error) {
     g_warning ("Failed to execute select hash prefix statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
     goto out;
   }
 
@@ -789,9 +818,11 @@ ephy_gsb_storage_update_client_state (EphyGSBStorage    *self,
   gboolean success;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
 
+  if (!self->is_operable)
+    return;
+
   if (clear) {
     sql = "UPDATE threats SET client_state=NULL "
           "WHERE threat_type=? AND platform_type=? AND threat_entry_type=?";
@@ -821,6 +852,7 @@ ephy_gsb_storage_update_client_state (EphyGSBStorage    *self,
   if (error) {
     g_warning ("Failed to execute update threat statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
@@ -842,9 +874,11 @@ ephy_gsb_storage_clear_hash_prefixes (EphyGSBStorage    *self,
   const char *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
 
+  if (!self->is_operable)
+    return;
+
   sql = "DELETE FROM hash_prefix WHERE "
         "threat_type=? AND platform_type=? AND threat_entry_type=?";
   statement = ephy_sqlite_connection_create_statement (self->db, sql, &error);
@@ -863,6 +897,7 @@ ephy_gsb_storage_clear_hash_prefixes (EphyGSBStorage    *self,
   if (error) {
     g_warning ("Failed to execute clear hash prefix statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
@@ -881,10 +916,12 @@ ephy_gsb_storage_get_hash_prefixes_to_delete (EphyGSBStorage    *self,
   guint index = 0;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (indices);
 
+  if (!self->is_operable)
+    return NULL;
+
   *num_prefixes = 0;
 
   sql = "SELECT value FROM hash_prefix WHERE "
@@ -915,6 +952,7 @@ ephy_gsb_storage_get_hash_prefixes_to_delete (EphyGSBStorage    *self,
   if (error) {
     g_warning ("Failed to execute select prefix value statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
@@ -931,7 +969,9 @@ ephy_gsb_storage_make_delete_hash_prefix_statement (EphyGSBStorage *self,
   GString *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
+
+  if (!self->is_operable)
+    return NULL;
 
   sql = g_string_new ("DELETE FROM hash_prefix WHERE "
                       "threat_type=? AND platform_type=? and threat_entry_type=? "
@@ -964,10 +1004,12 @@ ephy_gsb_storage_delete_hash_prefixes_batch (EphyGSBStorage      *self,
   gboolean free_statement = TRUE;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (prefixes);
 
+  if (!self->is_operable)
+    return NULL;
+
   if (stmt) {
     statement = stmt;
     ephy_sqlite_statement_reset (statement);
@@ -997,6 +1039,7 @@ ephy_gsb_storage_delete_hash_prefixes_batch (EphyGSBStorage      *self,
   if (error) {
     g_warning ("Failed to execute delete hash prefix statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
 out:
@@ -1020,10 +1063,12 @@ ephy_gsb_storage_delete_hash_prefixes_internal (EphyGSBStorage    *self,
   gsize num_prefixes;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (indices);
 
+  if (!self->is_operable)
+    return;
+
   LOG ("Deleting %lu hash prefixes...", num_indices);
 
   /* Move indices from the array to a hash table set. */
@@ -1083,10 +1128,12 @@ ephy_gsb_storage_delete_hash_prefixes (EphyGSBStorage    *self,
   gsize num_indices;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (tes);
 
+  if (!self->is_operable)
+    return;
+
   compression = json_object_get_string_member (tes, "compressionType");
   if (!g_strcmp0 (compression, GSB_COMPRESSION_TYPE_RICE)) {
     rice_indices = json_object_get_object_member (tes, "riceIndices");
@@ -1115,7 +1162,9 @@ ephy_gsb_storage_make_insert_hash_prefix_statement (EphyGSBStorage *self,
   GString *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
+
+  if (!self->is_operable)
+    return NULL;
 
   sql = g_string_new ("INSERT INTO hash_prefix "
                       "(cue, value, threat_type, platform_type, threat_entry_type) VALUES ");
@@ -1150,10 +1199,12 @@ ephy_gsb_storage_insert_hash_prefixes_batch (EphyGSBStorage      *self,
   gboolean free_statement = TRUE;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (prefixes);
 
+  if (!self->is_operable)
+    return;
+
   if (stmt) {
     statement = stmt;
     ephy_sqlite_statement_reset (statement);
@@ -1178,6 +1229,7 @@ ephy_gsb_storage_insert_hash_prefixes_batch (EphyGSBStorage      *self,
   if (error) {
     g_warning ("Failed to execute insert hash prefix statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
 out:
@@ -1196,10 +1248,12 @@ ephy_gsb_storage_insert_hash_prefixes_internal (EphyGSBStorage    *self,
   gsize num_batches;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (prefixes);
 
+  if (!self->is_operable)
+    return;
+
   LOG ("Inserting %lu hash prefixes of size %ld...", num_prefixes, prefix_len);
 
   ephy_gsb_storage_start_transaction (self);
@@ -1257,10 +1311,12 @@ ephy_gsb_storage_insert_hash_prefixes (EphyGSBStorage    *self,
   gsize num_prefixes;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (tes);
 
+  if (!self->is_operable)
+    return;
+
   compression = json_object_get_string_member (tes, "compressionType");
   if (!g_strcmp0 (compression, GSB_COMPRESSION_TYPE_RICE)) {
     rice_hashes = json_object_get_object_member (tes, "riceHashes");
@@ -1312,9 +1368,11 @@ ephy_gsb_storage_lookup_hash_prefixes (EphyGSBStorage *self,
   guint id = 0;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (cues);
 
+  if (!self->is_operable)
+    return NULL;
+
   sql = g_string_new ("SELECT value, negative_expires_at <= (CAST(strftime('%s', 'now') AS INT)) "
                       "FROM hash_prefix WHERE cue IN (");
   for (GList *l = cues; l && l->data; l = l->next)
@@ -1355,6 +1413,7 @@ ephy_gsb_storage_lookup_hash_prefixes (EphyGSBStorage *self,
     g_error_free (error);
     g_list_free_full (retval, (GDestroyNotify)ephy_gsb_hash_prefix_lookup_free);
     retval = NULL;
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
@@ -1388,9 +1447,11 @@ ephy_gsb_storage_lookup_full_hashes (EphyGSBStorage *self,
   guint id = 0;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (hashes);
 
+  if (!self->is_operable)
+    return NULL;
+
   sql = g_string_new ("SELECT value, threat_type, platform_type, threat_entry_type, "
                       "expires_at <= (CAST(strftime('%s', 'now') AS INT)) "
                       "FROM hash_full WHERE value IN (");
@@ -1439,6 +1500,7 @@ ephy_gsb_storage_lookup_full_hashes (EphyGSBStorage *self,
     g_error_free (error);
     g_list_free_full (retval, (GDestroyNotify)ephy_gsb_hash_full_lookup_free);
     retval = NULL;
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
@@ -1469,10 +1531,12 @@ ephy_gsb_storage_insert_full_hash (EphyGSBStorage    *self,
   const char *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (list);
   g_assert (hash);
 
+  if (!self->is_operable)
+    return;
+
   LOG ("Inserting full hash with duration %ld for list %s/%s/%s",
        duration, list->threat_type, list->platform_type, list->threat_entry_type);
 
@@ -1496,6 +1560,7 @@ ephy_gsb_storage_insert_full_hash (EphyGSBStorage    *self,
   ephy_sqlite_statement_step (statement, &error);
   if (error) {
     g_warning ("Failed to execute insert full hash statement: %s", error->message);
+    ephy_gsb_storage_recreate_db (self);
     goto out;
   }
 
@@ -1523,8 +1588,10 @@ ephy_gsb_storage_insert_full_hash (EphyGSBStorage    *self,
     goto out;
 
   ephy_sqlite_statement_step (statement, &error);
-  if (error)
+  if (error) {
     g_warning ("Failed to execute insert full hash statement: %s", error->message);
+    ephy_gsb_storage_recreate_db (self);
+  }
 
 out:
   if (statement)
@@ -1548,7 +1615,9 @@ ephy_gsb_storage_delete_old_full_hashes (EphyGSBStorage *self)
   const char *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
+
+  if (!self->is_operable)
+    return;
 
   LOG ("Deleting full hashes expired for more than %d seconds", EXPIRATION_THRESHOLD);
 
@@ -1573,6 +1642,7 @@ ephy_gsb_storage_delete_old_full_hashes (EphyGSBStorage *self)
   if (error) {
     g_warning ("Failed to execute delete full hash statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
@@ -1596,9 +1666,11 @@ ephy_gsb_storage_update_hash_prefix_expiration (EphyGSBStorage *self,
   const char *sql;
 
   g_assert (EPHY_IS_GSB_STORAGE (self));
-  g_assert (self->is_operable);
   g_assert (prefix);
 
+  if (!self->is_operable)
+    return;
+
   sql = "UPDATE hash_prefix "
         "SET negative_expires_at=(CAST(strftime('%s', 'now') AS INT)) + ? "
         "WHERE value=?";
@@ -1631,6 +1703,7 @@ ephy_gsb_storage_update_hash_prefix_expiration (EphyGSBStorage *self,
   if (error) {
     g_warning ("Failed to execute update hash prefix statement: %s", error->message);
     g_error_free (error);
+    ephy_gsb_storage_recreate_db (self);
   }
 
   g_object_unref (statement);
