@@ -64,7 +64,6 @@ struct _EphySession {
   GCancellable *save_cancellable;
   guint closing : 1;
   guint dont_save : 1;
-  guint loaded_page : 1;
 };
 
 #define SESSION_STATE           "type:session_state"
@@ -123,13 +122,8 @@ load_changed_cb (WebKitWebView  *view,
                  WebKitLoadEvent load_event,
                  EphySession    *session)
 {
-  if (ephy_web_view_load_failed (EPHY_WEB_VIEW (view)))
-    return;
-
-  if (load_event == WEBKIT_LOAD_FINISHED)
-    session->loaded_page = TRUE;
-
-  ephy_session_save (session);
+  if (!ephy_web_view_load_failed (EPHY_WEB_VIEW (view)))
+    ephy_session_save (session);
 }
 
 static void
@@ -551,12 +545,14 @@ typedef struct {
   char *title;
   gboolean loading;
   gboolean crashed;
+  gboolean pinned;
   WebKitWebViewSessionState *state;
 } SessionTab;
 
 static SessionTab *
 session_tab_new (EphyEmbed   *embed,
-                 EphySession *session)
+                 EphySession *session,
+                 GtkNotebook *notebook)
 {
   SessionTab *session_tab;
   const char *address;
@@ -585,6 +581,7 @@ session_tab_new (EphyEmbed   *embed,
   session_tab->crashed = (error_page == EPHY_WEB_VIEW_ERROR_PAGE_CRASH ||
                           error_page == EPHY_WEB_VIEW_ERROR_PROCESS_CRASH);
   session_tab->state = webkit_web_view_get_session_state (WEBKIT_WEB_VIEW (web_view));
+  session_tab->pinned = ephy_notebook_tab_is_pinned (EPHY_NOTEBOOK (notebook), embed);
 
   return session_tab;
 }
@@ -626,17 +623,17 @@ session_window_new (EphyWindow  *window,
   session_window = g_new0 (SessionWindow, 1);
   get_window_geometry (GTK_WINDOW (window), &session_window->geometry);
   session_window->role = g_strdup (gtk_window_get_role (GTK_WINDOW (window)));
+  notebook = GTK_NOTEBOOK (ephy_window_get_notebook (window));
 
   for (l = tabs; l != NULL; l = l->next) {
     SessionTab *tab;
 
-    tab = session_tab_new (EPHY_EMBED (l->data), session);
+    tab = session_tab_new (EPHY_EMBED (l->data), session, notebook);
     session_window->tabs = g_list_prepend (session_window->tabs, tab);
   }
   g_list_free (tabs);
   session_window->tabs = g_list_reverse (session_window->tabs);
 
-  notebook = GTK_NOTEBOOK (ephy_window_get_notebook (window));
   session_window->active_tab = gtk_notebook_get_current_page (notebook);
 
   return session_window;
@@ -718,6 +715,14 @@ write_tab (xmlTextWriterPtr writer,
       return ret;
   }
 
+  if (tab->pinned) {
+    ret = xmlTextWriterWriteAttribute (writer,
+                                       (const xmlChar *)"pinned",
+                                       (const xmlChar *)"true");
+    if (ret < 0)
+      return ret;
+  }
+
   if (tab->crashed) {
     ret = xmlTextWriterWriteAttribute (writer,
                                        (const xmlChar *)"crashed",
@@ -881,6 +886,14 @@ save_session_sync (GTask        *task,
   GList *w;
   int ret = -1;
 
+  /* If any web view has an insane URL, then something has probably gone wrong
+   * inside WebKit. For instance, if the web process is nonfunctional, the UI
+   * process could have an invalid URI property. Yes, this would be a WebKit
+   * bug, but Epiphany should be robust to such issues. Do not clobber an
+   * existing good session file with our new bogus state. Bug #768250. */
+  if (!session_seems_sane (data->windows))
+    return;
+
   buffer = xmlBufferCreate ();
   writer = xmlNewTextWriterMemory (buffer, 0);
   if (writer == NULL)
@@ -972,19 +985,6 @@ ephy_session_save_idle_cb (EphySession *session)
 
   session->save_source_id = 0;
 
-  /* If we have never successfully loaded any page, or any web view has an
-   * insane URL, then something has probably gone wrong inside WebKit. For
-   * instance, if the web process is nonfunctional, the UI process could have
-   * an invalid URI property. Yes, this would be a WebKit bug, but Epiphany
-   * should be robust to such issues. Do not clobber an existing good session
-   * file with our new bogus state. Bug #768250.
-   */
-  data = save_data_new (session);
-  if (!session->loaded_page || !session_seems_sane (data->windows)) {
-    save_data_free (data);
-    return G_SOURCE_REMOVE;
-  }
-
   if (session->save_cancellable) {
     g_cancellable_cancel (session->save_cancellable);
     g_object_unref (session->save_cancellable);
@@ -1000,6 +1000,7 @@ ephy_session_save_idle_cb (EphySession *session)
 
   g_application_hold (G_APPLICATION (ephy_shell_get_default ()));
   session->save_cancellable = g_cancellable_new ();
+  data = save_data_new (session);
   task = g_task_new (session, session->save_cancellable,
                      save_session_in_thread_finished_cb, NULL);
   g_task_set_task_data (task, data, (GDestroyNotify)save_data_free);
@@ -1135,14 +1136,18 @@ session_parse_embed (SessionParserContext *context,
                      const gchar         **names,
                      const gchar         **values)
 {
+  GtkWidget *notebook;
   const char *url = NULL;
   const char *title = NULL;
   const char *history = NULL;
   gboolean was_loading = FALSE;
   gboolean crashed = FALSE;
   gboolean is_blank_page = FALSE;
+  gboolean is_pin = FALSE;
   guint i;
 
+  notebook = ephy_window_get_notebook (context->window);
+
   for (i = 0; names[i]; i++) {
     if (strcmp (names[i], "url") == 0) {
       url = values[i];
@@ -1156,6 +1161,8 @@ session_parse_embed (SessionParserContext *context,
       crashed = strcmp (values[i], "true") == 0;
     } else if (strcmp (names[i], "history") == 0) {
       history = values[i];
+    } else if (strcmp (names[i], "pinned") == 0) {
+      is_pin = strcmp (values[i], "true") == 0;
     }
   }
 
@@ -1189,6 +1196,8 @@ session_parse_embed (SessionParserContext *context,
                                      context->window, NULL, flags,
                                      0);
 
+    ephy_notebook_tab_set_pinned (EPHY_NOTEBOOK (notebook), GTK_WIDGET (embed), is_pin);
+
     web_view = ephy_embed_get_web_view (embed);
     if (history) {
       guchar *data;
