@@ -22,6 +22,7 @@
 #include "ephy-embed-shell.h"
 #include "ephy-search-engine-manager.h"
 #include "ephy-suggestion.h"
+#include "ephy-window.h"
 
 #include <dazzle.h>
 #include <glib/gi18n.h>
@@ -192,7 +193,11 @@ should_add_bookmark_to_model (EphySuggestionModel *self,
                               const char          *title,
                               const char          *location)
 {
-  return strstr (title, search_string) || strstr (location, search_string);
+  g_autofree gchar *search_casefold = g_utf8_casefold (search_string, -1);
+  g_autofree gchar *title_casefold = g_utf8_casefold (title, -1);
+  g_autofree gchar *location_casefold = g_utf8_casefold (location, -1);
+
+  return strstr (title_casefold, search_casefold) || strstr (location_casefold, search_casefold);
 }
 
 static void
@@ -326,20 +331,26 @@ add_search_engines (EphySuggestionModel *self,
 
   for (guint i = 0; engines[i] != NULL; i++) {
     EphySuggestion *suggestion;
-    char *address;
-    g_autofree gchar *escaped_title = NULL;
-    g_autofree gchar *markup = NULL;
+    g_autofree char *address = NULL;
+    g_autofree char *escaped_title = NULL;
+    g_autofree char *markup = NULL;
+    g_autoptr(SoupURI) uri = NULL;
 
     address = ephy_search_engine_manager_build_search_address (manager, engines[i], query);
     escaped_title = g_markup_escape_text (engines[i], -1);
     markup = dzl_fuzzy_highlight (escaped_title, query, FALSE);
     suggestion = ephy_suggestion_new_without_subtitle (markup, engines[i], address);
+
+    uri = soup_uri_new (address);
+    if (uri) {
+      g_free (address);
+      address = g_strdup_printf ("%s://%s/", soup_uri_get_scheme (uri), soup_uri_get_host (uri));
+    }
+
     load_favicon (self, suggestion, address);
 
     g_sequence_append (self->items, suggestion);
     added++;
-
-    g_free (address);
   }
 
   g_strfreev (engines);
@@ -347,6 +358,70 @@ add_search_engines (EphySuggestionModel *self,
   return added;
 }
 
+static guint
+add_tabs (EphySuggestionModel *self,
+          const char          *query)
+{
+  GApplication *application;
+  EphyEmbedShell *shell;
+  EphyWindow *window ;
+  GtkWidget *notebook;
+  gint n_pages;
+  gint current;
+  guint added = 0;
+
+  shell = ephy_embed_shell_get_default ();
+  application = G_APPLICATION (shell);
+  window = EPHY_WINDOW (gtk_application_get_active_window (GTK_APPLICATION (application)));
+
+  if (!window)
+    return 0;
+
+  notebook = ephy_window_get_notebook (window);
+  n_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook));
+  current = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+
+  for (int i = 0; i < n_pages; i++) {
+    EphyEmbed *embed;
+    EphyWebView *webview;
+    EphySuggestion *suggestion;
+    g_autofree gchar *escaped_title = NULL;
+    g_autofree gchar *markup = NULL;
+    const gchar *display_address;
+    g_autofree gchar *address = NULL;
+    const gchar *title;
+    g_autofree gchar *title_casefold = NULL;
+    g_autofree gchar *display_address_casefold = NULL;
+    g_autofree gchar *query_casefold = NULL;
+
+    if (i == current)
+      continue;
+
+    embed = EPHY_EMBED (gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), i));
+    webview = ephy_embed_get_web_view (embed);
+    display_address = ephy_web_view_get_display_address (webview);
+    address = g_strdup_printf ("ephy-tab://%d", i);
+    title = webkit_web_view_get_title (WEBKIT_WEB_VIEW (webview));
+
+    display_address_casefold = g_utf8_casefold (display_address, -1);
+    query_casefold = g_utf8_casefold (query, -1);
+    if (title)
+      title_casefold = g_utf8_casefold (title, -1);
+
+    if ((title_casefold && strstr (title_casefold, query_casefold)) || strstr (display_address_casefold, query_casefold)) {
+      escaped_title = g_markup_escape_text (title, -1);
+      markup = dzl_fuzzy_highlight (escaped_title, query, FALSE);
+      suggestion = ephy_suggestion_new_with_custom_subtitle (markup, title, _("Switch to Tab"), address);
+      load_favicon (self, suggestion, display_address);
+
+      g_sequence_append (self->items, suggestion);
+      added++;
+    }
+  }
+
+  return added;
+}
+
 static void
 query_completed_cb (EphyHistoryService *service,
                     gboolean            success,
@@ -375,7 +450,8 @@ query_completed_cb (EphyHistoryService *service,
   self->items = g_sequence_new (g_object_unref);
 
   if (strlen (query) > 0) {
-    added = add_bookmarks (self, query);
+    added = add_tabs (self, query);
+    added += add_bookmarks (self, query);
     added += add_history (self, urls, query);
     added += add_search_engines (self, query);
   }
@@ -438,6 +514,7 @@ ephy_suggestion_model_get_suggestion_with_uri (EphySuggestionModel *self,
                                                const char          *uri)
 {
   GSequenceIter *iter;
+  g_autofree gchar *uri_casefold = g_utf8_casefold (uri, -1);
 
   g_assert (EPHY_IS_SUGGESTION_MODEL (self));
   g_assert (uri != NULL && *uri != '\0');
@@ -445,9 +522,12 @@ ephy_suggestion_model_get_suggestion_with_uri (EphySuggestionModel *self,
   for (iter = g_sequence_get_begin_iter (self->items);
        !g_sequence_iter_is_end (iter); iter = g_sequence_iter_next (iter)) {
     EphySuggestion *suggestion;
+    g_autofree gchar *suggestion_casefold = NULL;
 
     suggestion = g_sequence_get (iter);
-    if (strcmp (ephy_suggestion_get_uri (suggestion), uri) == 0)
+    suggestion_casefold = g_utf8_casefold (ephy_suggestion_get_uri (suggestion), -1);
+
+    if (strcmp (suggestion_casefold, uri_casefold) == 0)
       return suggestion;
   }
 
